Fixed function not found issue
This commit is contained in:
@@ -23,7 +23,7 @@ THE SOFTWARE.
|
|||||||
#include "hip/hip_runtime.h"
|
#include "hip/hip_runtime.h"
|
||||||
extern texture<float, 2, hipReadModeElementType> tex;
|
extern texture<float, 2, hipReadModeElementType> tex;
|
||||||
|
|
||||||
__global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
|
extern "C" __global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
|
||||||
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
||||||
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
|
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
|
||||||
outputData[y * width + x] = tex2D(tex, x, y);
|
outputData[y * width + x] = tex2D(tex, x, y);
|
||||||
|
|||||||
Reference in New Issue
Block a user